@@ -2,7 +2,7 @@
 A package of tools for capturing student code by matching it against patterns.
 """
 
-from pedal.cait.cait_api import (find_match, find_matches,
+from pedal.cait.cait_api import (find_match, find_matches, find_asts,
                                  parse_program,
                                  find_submatches, find_expr_sub_matches,
                                  def_use_error, data_state, data_type,
